#ifndef SCRAPPER_TABLEVIEW_H
#define SCRAPPER_TABLEVIEW_H

#include <QTableView>

class ScraperTableView : public QTableView
{
    Q_OBJECT
public:
    explicit ScraperTableView(QWidget *parent = nullptr);

signals:

public slots:
};

#endif // SCRAPPER_TABLEVIEW_H
